@@ -377,7 +377,7 @@ class StreamClient(object):
         self, id=None, foreign_id=None, time=None, set={}, unset=[]
     ):
         """
-        Partial update activity, via foreign ID or Foreign ID + timestamp
+        Partial update activity, via activity ID or Foreign ID + timestamp
 
         id: the activity ID
         foreign_id: the activity foreign ID
@@ -386,8 +386,6 @@ class StreamClient(object):
         unset: list of unset operations
         """
 
-        auth_token = self.create_jwt_token("activities", "*", feed_id="*")
-
         if id is None and (foreign_id is None or time is None):
             raise TypeError(
                 "The id or foreign_id+time parameters must be provided and not be None"
@@ -405,6 +403,34 @@ class StreamClient(object):
             data["foreign_id"] = foreign_id
             data["time"] = time
 
+        return self.activities_partial_update(updates=[data])
+
+    def activities_partial_update(self, updates=[]):
+        """
+        Partial update activity, via activity ID or Foreign ID + timestamp
+
+        :param updates: list of partial updates to perform.
+
+        eg.
+        [
+            {
+                "foreign_id": "post:1",
+                "time": datetime.datetime.utcnow(),
+                "set": {
+                    "product.name": "boots",
+                    "product.price": 7.99,
+                    "popularity": 1000,
+                    "foo": {"bar": {"baz": "qux"}},
+                },
+                "unset": ["product.color"]
+            }
+        ]
+        """
+
+        auth_token = self.create_jwt_token("activities", "*", feed_id="*")
+
+        data = {"changes": updates}
+
         return self.post("activity/", auth_token, data=data)
 
     def create_redirect_url(self, target_url, user_id, events):
